@@ -294,6 +294,23 @@ where
                 }
             }
 
+            "property" => {
+                self.input.skip_ws()?;
+
+                let at_rule_color_profile: PResult<PropertyRule> = self.parse();
+
+                match at_rule_color_profile {
+                    Ok(mut r) => {
+                        r.span.lo = at_rule_span.lo;
+
+                        return Ok(AtRule::Property(r));
+                    }
+                    Err(err) => {
+                        self.errors.push(err);
+                    }
+                }
+            }
+
             _ => {}
         }
 
@@ -515,16 +532,13 @@ where
             tok!("ident") => {
                 let custom_ident: CustomIdent = self.parse()?;
 
-                match &*custom_ident.value.to_ascii_lowercase() {
-                    "none" => {
-                        let span = self.input.cur_span()?;
+                if &*custom_ident.value.to_ascii_lowercase() == "none" {
+                    let span = self.input.cur_span()?;
 
-                        return Err(Error::new(
-                            span,
-                            ErrorKind::InvalidCustomIdent(stringify!(value)),
-                        ));
-                    }
-                    _ => {}
+                    return Err(Error::new(
+                        span,
+                        ErrorKind::InvalidCustomIdent(stringify!(value)),
+                    ));
                 }
 
                 Ok(KeyframesName::CustomIdent(custom_ident))
@@ -533,7 +547,7 @@ where
             _ => {
                 let span = self.input.cur_span()?;
 
-                return Err(Error::new(span, ErrorKind::Expected("ident or string")));
+                Err(Error::new(span, ErrorKind::Expected("ident or string")))
             }
         }
     }
@@ -598,7 +612,7 @@ where
             _ => {
                 let span = self.input.cur_span()?;
 
-                return Err(Error::new(span, ErrorKind::Expected("ident or percentage")));
+                Err(Error::new(span, ErrorKind::Expected("ident or percentage")))
             }
         }
     }
@@ -1813,3 +1827,25 @@ where
         })
     }
 }
+
+impl<I> Parse<PropertyRule> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<PropertyRule> {
+        let span = self.input.cur_span()?;
+        let name = self.parse()?;
+
+        expect!(self, "{");
+
+        let block = self.parse()?;
+
+        expect!(self, "}");
+
+        Ok(PropertyRule {
+            span: span!(self, span.lo),
+            name,
+            block,
+        })
+    }
+}
